@@ -42,7 +42,7 @@ diags_dict['[SII] 6731/6716'] = ('S2', 'L(6731)/L(6716)', 'RMS([E(6716), E(6731)
 diags_dict['[SII] 4069/4076'] = ('S2', 'L(4069)/L(4076)', 'RMS([E(4069), E(4076)])')
 diags_dict['[SII] 4072+/6720+'] = ('S2', '(L(4069)+L(4076))/(L(6716)+L(6731))',
               'RMS([E(6716)*L(6716)/(L(6716)+L(6731)), E(6731)*L(6731)/(L(6716)+L(6731)), E(4069)*L(4069)/(L(4069)+L(4076)), E(4076)*L(4076)/(L(4069)+L(4076))])')
-diags_dict['[SIII] 18.7m/33.6m'] = ('S3', 'L(187000)/L(336000)', 'RMS([E(336000), E(187000)])')
+diags_dict['[SIII] 18.7m/33.5m'] = ('S3', 'L(187000)/L(335000)', 'RMS([E(335000), E(187000)])')
 diags_dict['[SIII] 6312/18.7m'] = ('S3', 'L(6312)/L(187000)', 'RMS([E(187000), E(6312)])')
 diags_dict['[SIII] 9069/18.7m'] = ('S3', 'L(9069)/L(187000)', 'RMS([E(187000), E(9069)])')
 diags_dict['[SIII] 6312/9200+'] = ('S3', 'L(6312)/(L(9069)+L(9531))', 'RMS([E(9069)*L(9069)/(L(9069)+L(9531)), E(9531)*L(9531)/(L(9069)+L(9531)), E(6312)])')
@@ -366,7 +366,7 @@ class Diagnostics(object):
         old_level = pn.log_.level
         pn.log_.level = 1
         def I(i, j):
-            wave = self.atomDict[atom].atom.wave_Ang[i - 1, j - 1]
+            wave = atom.wave_Ang[i - 1, j - 1]
             corrIntens = obs.getLine(sym, spec, wave).corrIntens
             return corrIntens
         def L(wave):
@@ -379,13 +379,13 @@ class Diagnostics(object):
         
         for label in diags_dict:
             atom, diag_expression, error = diags_dict[label]
-            if atom not in self.atomDict:
-                self.atomDict[atom] = pn.Atom(atom=atom)
             sym, spec = parseAtom(atom)
             try:
                 diag_value = eval(diag_expression)
+                if atom not in self.atomDict:
+                    self.atomDict[atom] = pn.Atom(atom=atom)
                 self.addDiag(label)
-            except:
+            except Exception as ex:
                 pass
         pn.log_.level = old_level
     
@@ -418,7 +418,7 @@ class Diagnostics(object):
             pn.log_.warn('Try to add clabel in undefined label {0}'.format(label), calling=self.calling)
     
     
-    def plot(self, emis_grids, obs, quad=True, i_obs=None, alpha=0.3):
+    def plot(self, emis_grids, obs, quad=True, i_obs=None, alpha=0.3, ax=None):
         """
         PLotting tool to generate Te-Ne diagrams.
         
@@ -454,7 +454,10 @@ class Diagnostics(object):
         if (i_obs is None) and (obs.n_obs != 1):
             self.log_.error('i_obs must be specified when obs is multiple. try i_obs=0', calling=self.calling)
             return None
-        
+        if ax is None:
+            f, ax = plt.subplots()
+        else:
+            f = plt.gcf()
         X = np.log10(emis_grids[emis_grids.keys()[0]].den2D)
         Y = emis_grids[emis_grids.keys()[0]].tem2D
         for label in self.diags:
@@ -531,15 +534,15 @@ class Diagnostics(object):
                     style = style_dic[atom[-1]]
                     if tol_value > 0.:
                         levels = [(1 - tol_value) * diag_value, (1 + tol_value) * diag_value]
-                        CS = plt.contourf(X, Y, diag_map, levels=levels, alpha=alpha, colors=col)
-                    CS = plt.contour(X, Y, diag_map, levels=[diag_value], colors=col, linestyles=style)
-                    plt.xlabel(r'log(n$_{\rm e}$) [cm$^{-3}$]')
-                    plt.ylabel(r'T$_{\rm e}$ [K]')
+                        CS = ax.contourf(X, Y, diag_map, levels=levels, alpha=alpha, colors=col)
+                    CS = ax.contour(X, Y, diag_map, levels=[diag_value], colors=col, linestyles=style)
+                    ax.set_xlabel(r'log(n$_{\rm e}$) [cm$^{-3}$]')
+                    ax.set_ylabel(r'T$_{\rm e}$ [K]')
                     if len(diag) >= 4:
                         fmt = diag[3]
                     else:
                         fmt = '[{0}{1}]'.format(atom[0:-1], int_to_roman(int(atom[-1])))
-                    plt.clabel(CS, inline=True, fmt=fmt, fontsize=15, colors=col)
+                    ax.clabel(CS, inline=True, fmt=fmt, fontsize=15, colors=col)
                     if type(diag_value) is np.ndarray:
                         diag_value = diag_value[0]
                     self.log_.message('plotting {0}: {1} = {2:.2} with error of {3:.2} %'.format(fmt, label, diag_value, tol_value * 100),
