@@ -176,7 +176,7 @@ class EmisGrid(object):
 
 
     def plotContours(self, to_eval, low_level=None, high_level=None, n_levels=20,
-                      linestyles='-', clabels=True, log_levels=True, title=None, **kwargs):
+                      linestyles='-', clabels=True, log_levels=True, title=None, ax=None, **kwargs):
         """
         Plot a contour map of the diagnostic defined by to_eval.
         
@@ -221,12 +221,17 @@ class EmisGrid(object):
             levels = 10. ** (np.linspace(low_level, high_level, n_levels))
             if title is None:
                 title = '[%s%s]: %s' % (self.elem, int_to_roman(int(self.spec)), to_eval)
-        CS = plt.contour(X, Y, Z, levels=levels, linestyles=linestyles, **kwargs)
+        
+        if ax is None:
+            f, ax = plt.subplots()
+        else:
+            f = plt.gcf()
+        CS = ax.contour(X, Y, Z, levels=levels, linestyles=linestyles, **kwargs)
         if clabels:
-            plt.clabel(CS, CS.levels[::3], inline=True, fontsize=12, colors='black')
-        plt.xlabel(r'log(n$_{\rm e}$) [cm$^{-3}$]')
-        plt.ylabel(r'T$_{\rm e}$ [K]')
-        plt.title(title)
+            ax.clabel(CS, CS.levels[::3], inline=True, fontsize=12, colors='black')
+        ax.set_xlabel(r'log(n$_{\rm e}$) [cm$^{-3}$]')
+        ax.set_ylabel(r'T$_{\rm e}$ [K]')
+        ax.set_title(title)
 
 
     def plotLineRatio(self, to_eval, par=None, par_low=None, par_high=None, n_par=10,
@@ -347,7 +352,8 @@ def getEmisGridDict(elem_list=None, spec_list=None, atom_list=None, restore=True
         if atom_list is not None:
             atoms = atom_list
         else:
-            atoms = pn.atomicData.getAllAtoms()
+# VL Removed 13 March 2015 because it made the code ignore the elem keyword             
+#            atoms = pn.atomicData.getAllAtoms()
             if (elem_list is None) and (spec_list is None):
                 atoms = pn.atomicData.getAllAtoms()
             else:
