@@ -94,11 +94,26 @@ class ICF(object):
                                        'icf': '1',
                                        'type': 'All',
                                        'comment': 'just summing visible ions'},
+                         'direct_Mg.45':{'elem': 'Mg',
+                                       'atom': 'abun["Mg4"] + abun["Mg5"]',
+                                       'icf': '1',
+                                       'type': 'All',
+                                       'comment': 'just summing visible ions'},
+                         'direct_Ar.23':{'elem': 'Ar',
+                                       'atom': 'abun["Ar2"] + abun["Ar3"]',
+                                       'icf': '1',
+                                       'type': 'All',
+                                       'comment': 'just summing visible ions'},
                          'direct_Cl.23':{'elem': 'Cl',
                                        'atom': 'abun["Cl2"] + abun["Cl3"]',
                                        'icf': '1',
                                        'type': 'All',
                                        'comment': 'just summing visible ions'},
+                         'direct_Cl.34':{'elem': 'Cl',
+                                       'atom': 'abun["Cl3"] + abun["Cl4"]',
+                                       'icf': '1',
+                                       'type': 'All',
+                                       'comment': 'just summing visible ions'},
                          'direct_Cl.234':{'elem': 'Cl',
                                        'atom': 'abun["Cl2"] + abun["Cl3"] + abun["Cl4"]',
                                        'icf': '1',
@@ -129,6 +144,17 @@ class ICF(object):
                                        'icf': '(0.753 + 0.142 * abun["O3"] / (abun["O2"] + abun["O3"]) + 0.171 / abun["O3"] * (abun["O2"] + abun["O3"]))',
                                        'type': 'HII',
                                        'comment': 'Based on a grid of photoionization models'},
+# PHCD07_16 and 17 added on December 11, 2014
+                         'PHCD07_16': {'elem': 'Ar',
+                                       'atom': '(abun["Ar3"] + abun["Ar4"])',
+                                       'icf': '(0.928 + 0.364 * (1 - abun["O3"] / (abun["O2"] + abun["O3"])) + 0.006 / (1 - abun["O3"] / (abun["O2"] + abun["O3"])))',
+                                       'type': 'HII',
+                                       'comment': 'Based on a grid of photoionization models'},
+                         'PHCD07_17': {'elem': 'Ar',
+                                       'atom': 'abun["Ar3"]',
+                                       'icf': '(0.596 + 0.967 * (1 - abun["O3"] / (abun["O2"] + abun["O3"])) + 0.077 / (1 - abun["O3"] / (abun["O2"] + abun["O3"])))',
+                                       'type': 'HII',
+                                       'comment': 'Based on a grid of photoionization models'},
 # Cited in PHCD07 but originally proposed by ITL94. Authorship changed in the code 3/Nov/2014. 
 #                         'PHCD07_14': {'elem': 'Ar',
                          'ITL94_19': {'elem': 'Ar',
@@ -141,143 +167,243 @@ class ICF(object):
                          'ITL94_20': {'elem': 'Ar',
                                        'atom': 'abun["Ar3"]',
                                        'icf': '(0.15 + 2.39 * abun["O2"] / (abun["O2"] + abun["O3"]) - 2.64 * (abun["O2"] / (abun["O2"] + abun["O3"]))**2.)**-1.',
-                                       'type': 'HII',
+                                       'type': 'HII',   
                                        'comment': 'Based on a grid of photoionization models'},
                          'PTPR92_21':{'elem': 'He',
                                        'atom': 'abun["He2"]',
                                        'icf': '(1 + abun["S2"] / (elem_abun["KB94_A36.10"] -  abun["S2"]))',
                                        'type': 'HII',
                                        'comment': 'Based on ionization potentials'},
+                         
+                         'KB94_A0': {'elem': 'N',
+                                    'atom': 'abun["N2"] + abun["N3"] + abun["N4"] + abun["N5"]',
+                                    'icf': '1',
+                                     'type': 'PNe',
+                                     'comment': 'Sum of all N ions from N+ to N4+'},
+                         
                          'KB94_A1.6': {'elem': 'N',
                                      'atom': 'abun["N2"]',
                                      'icf': 'elem_abun["KB94_A6"]  / abun["O2"]',
                                      'type': 'PNe',
-                                      'comment': 'Based on a grid of photoionization models. To be used if both O4 and N5 detected'},
+# Comment clarified on 12 Dec 2014 
+#                                      'comment': 'Based on a grid of photoionization models. To be used if both O4 and N5 detected'},
+                                      'comment': 'Based on a grid of photoionization models. To be used if both O4 and N5 are detected, but O5 is not'},
                          'KB94_A1.8': {'elem': 'N',
                                      'atom': 'abun["N2"]',
                                      'icf': 'elem_abun["KB94_A8"]  / abun["O2"]',
                                      'type': 'PNe',
-                                      'comment': 'Based on a grid of photoionization models. To be used if both O4 and N5 detected'},
+# wrong comment. Corrected 12 Dec 2014
+#                                     'comment': 'Based on a grid of photoionization models. To be used if both O4 and N5 detected'},
+                                     'comment': 'Based on a grid of photoionization models. To be used if both O3 and are N5 detected, but O4 is not'},
                          'KB94_A1.10': {'elem': 'N',
                                      'atom': 'abun["N2"]',
                                      'icf': 'elem_abun["KB94_A10"]  / abun["O2"]',
                                      'type': 'PNe',
-                                      'comment': 'Based on a grid of photoionization models. To be used if both O4 and N5 detected'},
+# wrong comment. Corrected 12 Dec 2014
+#                                      'comment': 'Based on a grid of photoionization models. To be used if both O4 and N5 detected'},
+                                      'comment': 'Based on a grid of photoionization models. To be used if only O2 and O3 are detected'},
                          'KB94_A6': {'elem': 'O',
                                      'atom': 'abun["O2"] + abun["O3"] + abun["O4"]',
                                       'icf': '1 / (1 - 0.95 * abun["N5"] / (abun["N2"] + abun["N3"] + abun["N4"] + abun["N5"]))',
                                       'type': 'PNe',
-                                      'comment': 'Based on a grid of photoionization models. To be used if both O4 and N5 detected'},
+# Comment clarified on 12 Dec 2014 
+#                                      'comment': 'Based on a grid of photoionization models. To be used if both O4 and N5 detected'},
+                                      'comment': 'Based on a grid of photoionization models. To be used if both O4 and N5 are detected, but O5 is not'},
                          'KB94_A8': {'elem': 'O',
                                      'atom': 'abun["O2"] + abun["O3"]',
                                      'icf': '(abun["N2"] + abun["N3"] + abun["N4"] + abun["N5"]) / (abun["N2"] + abun["N3"])',
                                      'type': 'PNe',
-                                     'comment': 'Based on a grid of photoionization models. To be used if N5 detected and O4 not detected'},
+# Comment clarified on 12 Dec 2014 
+#                                     'comment': 'Based on a grid of photoionization models. To be used if N5 detected and O4 not detected'},
+                                     'comment': 'Based on a grid of photoionization models. To be used if N5 detected, but neither O3 nor O4 are'},
                          'KB94_A10': {'elem': 'O',
                                       'atom': 'abun["O2"] + abun["O3"]',
                                       'icf': '((abun["He2"] + abun["He3"]) / abun["He2"])**(2./3.)',
                                       'type': 'PNe',
-                                      'comment': 'Based on a grid of photoionization models. To be used if only O2 and O3 detected'},
-                         'KB94_A10.5': {'elem': 'C',
-                                        'atom': 'abun["C2"] + abun["C3"] + abun["C4"] + abun["C5"]',
-                                        'icf': '1',
-                                        'type': 'PNe',
-                                        'comment': 'Based on a grid of photoionization models. To be used if no He3 detected and C2, C3, and C4 detected'},
-                         'KB94_A12': {'elem': 'C',
+                                      'comment': 'Based on a grid of photoionization models. To be used if only O2 and O3 are detected'},
+                         'KB94_A10b': {'elem': 'O',
+                                      'atom': 'abun["O2"] + abun["O3"]',
+                                      'icf': '1',
+                                      'type': 'PNe',
+                                      'comment': 'Based on a grid of photoionization models. To be used if only O2 and O3 are detected and no HeII is seen'},
+# Wrong  12 Dec 2014
+#                         'KB94_A10.5': {'elem': 'C',
+#                                        'atom': 'abun["C2"] + abun["C3"] + abun["C4"] + abun["C5"]',
+#                                        'icf': '1',
+#                                        'type': 'PNe',
+#                                        'comment': 'Based on a grid of photoionization models. To be used if no He3 detected and C2, C3, and C4 detected'},
+# Misleading comment clarified on 12 Dec 2014 
+                        'KB94_A12': {'elem': 'C',
                                       'atom': 'abun["C3"] + abun["C4"]',
                                       'icf': '(abun["O2"] + abun["O3"]) / abun["O3"]',
                                       'type': 'PNe',
-                                      'comment': 'Based on a grid of photoionization models. To be used if no C II lines detected'},
-                         'KB94_A13.6': {'elem': 'C',
-                                      'atom': 'abun["C3"]',
-                                      'icf': 'elem_abun["KB94_A6"] / abun["O3"]',
-                                      'type': 'PNe',
-                                      'comment': 'Based on a grid of photoionization models. To be used if no C II lines detected'},
-                         'KB94_A13.8': {'elem': 'C',
-                                      'atom': 'abun["C3"]',
-                                      'icf': 'elem_abun["KB94_A8"] / abun["O3"]',
-                                      'type': 'PNe',
-                                      'comment': 'Based on a grid of photoionization models. To be used if no C II lines detected'},
+#                                      'comment': 'Based on a grid of photoionization models. To be used if no C II lines detected'},
+                                      'comment': 'Based on a grid of photoionization models. To be used if no C2 lines available and C4 and He3 are not present'},
+# Wrong because eq. A10 does not point to eq. A6 (no O4 present). 12 Dec 2014
+#                         'KB94_A13.6': {'elem': 'C',
+#                                      'atom': 'abun["C3"]',
+#                                      'icf': 'elem_abun["KB94_A6"] / abun["O3"]',
+#                                      'type': 'PNe',
+#                                      'comment': 'Based on a grid of photoionization models. To be used if no C II lines detected'},
+#
+# Wrong because eq. A10 does not point to eq. A8 (no N5 present)
+#                         'KB94_A13.8': {'elem': 'C',
+#                                      'icf': 'elem_abun["KB94_A8"] / abun["O3"]',
+#                                      'atom': 'abun["C3"]',
+#                                      'type': 'PNe',
+#                                      'comment': 'Based on a grid of photoionization models. To be used if no C II lines detected'},
+# Misleading comment clarified on 12 Dec 2014 
                          'KB94_A13.10': {'elem': 'C',
                                       'atom': 'abun["C3"]',
                                       'icf': 'elem_abun["KB94_A10"] / abun["O3"]',
                                       'type': 'PNe',
-                                      'comment': 'Based on a grid of photoionization models. To be used if no C II lines detected'},
+#                                     'comment': 'Based on a grid of photoionization models. To be used if no C II lines detected'},
+                                      'comment': 'Based on a grid of photoionization models. To be used if C5 is not present; only C3 lines are detected; O3 also detected; He2 and He3 also detected'},
+                         'KB94_A13.10b': {'elem': 'C',
+                                      'atom': 'abun["C3"]',
+                                      'icf': 'elem_abun["KB94_A10b"] / abun["O3"]',
+                                      'type': 'PNe',
+#                                     'comment': 'Based on a grid of photoionization models. To be used if no C II lines detected'},
+                                      'comment': 'Based on a grid of photoionization models. To be used if C5 is not present; only C3 lines are detected; O3 also detected; He2 also detected, He3 Not'},
+# Clarified comment 12 Dec 2014
                          'KB94_A16': {'elem': 'C',
                                       'atom': 'abun["C2"] + abun["C3"] + abun["C4"]',
                                       'icf': '1 / (1 - 2.7 * abun["N5"] / (abun["N2"] + abun["N3"] + abun["N4"] + abun["N5"]))',
                                       'type': 'PNe',
-                                      'comment': 'Based on a grid of photoionization models. Valid for high excitation PNe if icf < 5'},
+#                                     'comment': 'Based on a grid of photoionization models. Valid for high excitation PNe if icf < 5'},
+                                       'comment': 'Based on a grid of photoionization models. To be used in high excitation PNe where C5 is present (as inferred from He3 and N5). Valid if icf < 5'},
+# Clarified comment 12 Dec 2014
                          'KB94_A19': {'elem': 'C',
                                       'atom': 'abun["C2"] + abun["C3"] + abun["C4"]',
                                       'icf': '(1 + abun["N5"] / (abun["N2"] + abun["N3"] + abun["N4"]))',
                                       'type': 'PNe',
-                                      'comment': 'Based on a grid of photoionization models. Valid for extremely high excitation PNe if icf > 5'},
+#                                      'comment': 'Based on a grid of photoionization models. Valid for extremely high excitation PNe if icf > 5'},
+                                       'comment': 'Based on a grid of photoionization models. To be used in very high excitation PNe where C5 is present (as inferred from He3 and N5). Valid if icf > 5'},
                          'KB94_A21': {'elem': 'C',
                                       'atom': 'abun["C2"] + abun["C3"] + abun["C4"]',
                                       'icf': '((abun["He2"] + abun["He3"]) / abun["He2"])**(1./3.)',
                                       'type': 'PNe',
                                       'comment': 'Based on a grid of photoionization models. Valid if He3 present and N5 absent'},
+# Clarified comment 12 Dec 2014
                          'KB94_A26': {'elem': 'C',
                                       'atom': 'abun["C2"] + abun["C3"] + abun["C4"]',
                                       'icf': '(abun["O2"] + abun["O3"]) / abun["O3"] * ((abun["He2"] + abun["He3"]) / abun["He2"])**(1./3.)',
                                       'type': 'PNe',
-                                      'comment': 'Based on a grid of photoionization models. Valid if N4 or N5 not seen'},
+#                                      'comment': 'Based on a grid of photoionization models. Valid if C5 is present but N4 or N5 not seen'},
+                                      'comment': 'Based on a grid of photoionization models. Valid if C5 is present but only optical data are available, so N4 and N5 are not seen'},
                          'KB94_A27': {'elem': 'Ne',
                                       'atom': 'abun["Ne3"] + abun["Ne5"]',
                                       'icf': '1.5',
                                       'type': 'PNe',
-                                      'comment': 'Based on a grid of photoionization models. Valid if N4 or N5 not seen'},
+# Wrong comment. Corrected 19 Dec 2014
+#                                      'comment': 'Based on a grid of photoionization models. Valid if N4 or N5 not seen'},
+                                      'comment': 'Based on a grid of photoionization models. Valid if Ne3 and Ne5 are seen and Ne4 is not'},
+#
+# Unsure about this icf. I don't know if eq. 28 can be mixed with eq. 6. In any case, I explicitly set out the conditions of eq. 6 in the comment.
                          'KB94_A28.6':{'elem': 'Ne',
                                      'atom': 'abun["Ne3"]',
                                      'icf': 'elem_abun["KB94_A6"]  / abun["O3"]',
                                       'type': 'PNe',
-                                      'comment': 'Based on a grid of photoionization models. Valid if N4 or N5 not seen'},
+# Wrong comment. Corrected 19 Dec 2014
+#                                      'comment': 'Based on a grid of photoionization models. Valid if N4 or N5 not seen'},
+                                      'comment': 'Based on a grid of photoionization models. Valid if neither Ne4 nor Ne5 are seen, both O4 and N5 are detected, but O5 is not'},
+#
+# Unsure about this icf. I don't know if eq. 28 can be mixed with eq. 8. In any case, I explicitly set out the conditions of eq. 6 in the comment.
                          'KB94_A28.8':{'elem': 'Ne',
                                      'atom': 'abun["Ne3"]',
                                      'icf': 'elem_abun["KB94_A8"]  / abun["O3"]',
                                       'type': 'PNe',
-                                      'comment': 'Based on a grid of photoionization models. Valid if N4 or N5 not seen'},
+# Wrong comment. Corrected 19 Dec 2014
+#                                      'comment': 'Based on a grid of photoionization models. Valid if N4 or N5 not seen'},
+                                      'comment': 'Based on a grid of photoionization models. Valid if neither Ne4 nor Ne5 are seen, N5 is detected, but neither O3 nor O4 are'},
+#
+# Unsure about this icf. I don't know if eq. 28 can be mixed with eq. 10. In any case, I explicitly set out the conditions of eq. 6 in the comment.
                          'KB94_A28.10':{'elem': 'Ne',
                                      'atom': 'abun["Ne3"]',
                                      'icf': 'elem_abun["KB94_A10"]  / abun["O3"]',
                                       'type': 'PNe',
-                                      'comment': 'Based on a grid of photoionization models. Valid if N4 or N5 not seen'},
-                         'KB94_A30.6': {'elem': 'Ar',
+# Wrong comment. Corrected 19 Dec 2014
+#                                      'comment': 'Based on a grid of photoionization models. Valid if N4 or N5 not seen'},
+                                      'comment': 'Based on a grid of photoionization models. Valid if neither Ne4 nor Ne5 are seen, if C5 is not present; only C3 lines are detected; O3 also detected; He2 and He3 also detected'},
+                         'KB94_A28.10b':{'elem': 'Ne',
+                                     'atom': 'abun["Ne3"]',
+                                     'icf': 'elem_abun["KB94_A10b"]  / abun["O3"]',
+                                      'type': 'PNe',
+# Wrong comment. Corrected 19 Dec 2014
+#                                      'comment': 'Based on a grid of photoionization models. Valid if N4 or N5 not seen'},
+                                      'comment': 'Based on a grid of photoionization models. Valid if neither Ne4 nor Ne5 are seen, if C5 is not present; only C3 lines are detected; O3 also detected; He2 detected, He3 not.'},
+# 26 Dec 2014 These icfs are temporarily commented out because they must be checked. The comments, at the very least, are wrong, and thee icfs may be physically wrong.  
+                         'KB94_A30.0': {'elem': 'Ar',
                                      'atom': 'abun["Ar3"] + abun["Ar4"] + abun["Ar5"]',
-                                     'icf': '1./(1. - abun["N2"] / elem_abun["KB94_A1.6"])',
                                      'type': 'PNe',
-                                      'comment': 'Based on a grid of photoionization models. To be used if both O4 and N5 detected'},
-                         'KB94_A30.8': {'elem': 'Ar',
-                                     'atom': 'abun["Ar3"] + abun["Ar4"] + abun["Ar5"]',
-                                     'icf': '1./(1. - abun["N2"] / elem_abun["KB94_A1.8"])',
-                                     'type': 'PNe',
-                                      'comment': 'Based on a grid of photoionization models. To be used if both O4 and N5 detected'},
+                                     'icf': '1./(1. - abun["N2"] / elem_abun["KB94_A0"])',
+                                      'comment': 'Based on a grid of photoionization models. To be used if N+ to N4+ are seen'},
                          'KB94_A30.10': {'elem': 'Ar',
                                      'atom': 'abun["Ar3"] + abun["Ar4"] + abun["Ar5"]',
                                      'icf': '1./(1. - abun["N2"] / elem_abun["KB94_A1.10"])',
                                      'type': 'PNe',
-                                      'comment': 'Based on a grid of photoionization models. To be used if both O4 and N5 detected'},
+                                      'comment': 'Based on a grid of photoionization models. To be used if He2 and He3 are detected.'},
+                         'KB94_A30.10b': {'elem': 'Ar',
+                                     'atom': 'abun["Ar3"] + abun["Ar4"] + abun["Ar5"]',
+                                     'icf': '1./(1. - abun["N2"] / elem_abun["KB94_A1.10b"])',
+                                     'type': 'PNe',
+                                      'comment': 'Based on a grid of photoionization models. To be used if He2 is detected.and He3 not.'},
+# end block of commented icfs
                          'KB94_A32': {'elem': 'Ar',
                                      'atom': 'abun["Ar3"]',
                                      'icf': '1.87',
                                      'type': 'PNe',
-                                      'comment': 'Based on a grid of photoionization models. To be used if both O4 and N5 detected'},
+# Wrong comment. Corrected 26 Dec 2014
+#                                      'comment': 'Based on a grid of photoionization models. To be used if both O4 and N5 detected'},
+                                     'comment': 'Based on a grid of photoionization models. To be used when only Ar3 is observed'},
                          'KB94_A36.6':{'elem': 'S',
                                      'atom': 'abun["S2"] + abun["S3"]',
-                                     'icf': ' (1-(1 - abun["O2"]/elem_abun["KB94_A6"])**3)**(-1./3.)',
+                                     'icf': ' (1 - (1 - abun["O2"]/elem_abun["KB94_A6"])**3)**(-1./3.)',
                                       'type': 'PNe',
-                                      'comment': 'Based on a grid of photoionization models. Valid if N4 or N5 not seen'},
+# Wrong comment. Corrected 26 Dec 2014
+#                                      'comment': 'Based on a grid of photoionization models. To be used if both O4 and N5 detected'},
+                                      'comment': 'Based on a grid of photoionization models. Valid if both S2 and S3 detected'},
                          'KB94_A36.8':{'elem': 'S',
                                      'atom': 'abun["S2"] + abun["S3"]',
                                      'icf': ' (1-(1 - abun["O2"]/elem_abun["KB94_A8"])**3)**(-1./3.)',
                                       'type': 'PNe',
-                                      'comment': 'Based on a grid of photoionization models. Valid if N4 or N5 not seen'},
+# Wrong comment. Corrected 26 Dec 2014
+#                                      'comment': 'Based on a grid of photoionization models. To be used if both O4 and N5 detected'},
+                                      'comment': 'Based on a grid of photoionization models. Valid if both S2 and S3 detected'},
                          'KB94_A36.10':{'elem': 'S',
                                      'atom': 'abun["S2"] + abun["S3"]',
                                      'icf': ' (1-(1 - abun["O2"]/elem_abun["KB94_A10"])**3)**(-1./3.)',
                                       'type': 'PNe',
-                                      'comment': 'Based on a grid of photoionization models. Valid if N4 or N5 not seen'},
+# Wrong comment. Corrected 26 Dec 2014
+#                                      'comment': 'Based on a grid of photoionization models. To be used if both O4 and N5 detected'},
+                                      'comment': 'Based on a grid of photoionization models. Valid if both S2 and S3 detected. He2 and He3 detected.'},
+                         'KB94_A36.10b':{'elem': 'S',
+                                     'atom': 'abun["S2"] + abun["S3"]',
+                                     'icf': ' (1-(1 - abun["O2"]/elem_abun["KB94_A10b"])**3)**(-1./3.)',
+                                      'type': 'PNe',
+# Wrong comment. Corrected 26 Dec 2014
+#                                      'comment': 'Based on a grid of photoionization models. To be used if both O4 and N5 detected'},
+                                      'comment': 'Based on a grid of photoionization models. Valid if both S2 and S3 detected. He2 detected, He3 not.'},
+# Added 26 Dec 2014
+# 26 Dec 2014 These icfs are temporarily commented out because they must be still be checked. 
+#                         'KB94_A38.6':{'elem': 'S',
+#                                     'atom': 'abun["S2"]',
+#                                     'icf': '((1 - (1 - abun["O2"]/elem_abun["KB94_A6"])**3)**(-1./3.)*(5.677 + (abun["O3"]/abun["O2"])**(0.433))',
+#                                      'type': 'PNe',
+#                                      'comment': 'Based on a grid of photoionization models and the S3/S2 ratio of a sample of PNe. Valid if S2 is detected but S3 is not detected'},
+# Added 26 Dec 2014
+#                         'KB94_A38.8':{'elem': 'S',
+#                                     'atom': 'abun["S2"]',
+#                                     'icf': '((1 - (1 - abun["O2"]/elem_abun["KB94_A8"])**3)**(-1./3.)*(5.677 + (abun["O3"]/abun["O2"])**(0.433))',
+#                                      'type': 'PNe',
+#                                      'comment': 'BBased on a grid of photoionization models and the S3/S2 ratio of a sample of PNe. Valid if S2 is detected but S3 is not detected'},
+# Added 26 Dec 2014
+#                         'KB94_A38.10':{'elem': 'S',
+#                                     'atom': 'abun["S2"]',
+#                                     'icf': '((1 - (1 - abun["O2"]/elem_abun["KB94_A10"])**3)**(-1./3.)*(5.677 + (abun["O3"]/abun["O2"])**(0.433))',
+#                                      'type': 'PNe',
+#                                      'comment': 'Based on a grid of photoionization models and the S3/S2 ratio of a sample of PNe. Valid if S2 is detected but S3 is not detected'},
+# end commented block
                          'KH01_4a': {'elem': 'He',
                                      'atom': 'abun["He2"] + abun["He3"]',
                                      'icf': '1',
@@ -461,6 +587,12 @@ class ICF(object):
                                        'icf': '(0.05 + 2.21 * abun["O3"] / (abun["O2"] + abun["O3"]) - 2.77 * (abun["O3"] / (abun["O2"] + abun["O3"]))**2 + 1.74 * (abun["O3"] / (abun["O2"] + abun["O3"]))**3) * elem_abun["DIMS14_12"] / abun["O3"]',
                                        'type': 'PNe',
                                        'comment': 'Based on photoionization models'},
+# To be completed
+#                         'Sal07_Kr1': {'elem': 'Kr',
+#                                       'atom':'abun["Kr3"] + abun["Kr4"]', 
+#                                       'icf': 'elem_abun["DIMS14_12"]/(abun["Ar3"] + abun["ar4"])',
+#                                       'type': 'PNe',
+#                                       'comment': 'Based on photoionization models'},}
                          
                          }
         
@@ -529,6 +661,8 @@ class ICF(object):
                                       'url': 'http://adsabs.harvard.edu/abs/2007A%26A...463..265G'},
                              'PTPR92': {'ref': 'Peimbert, Torres-Peimbert and Ruiz 1992, RMAA, 24, 155',
                                         'url': 'http://adsabs.harvard.edu/abs/1992RMxAA..24..155P'},
+                             'Sal07': {'ref': 'Sharpee et al 2007, MNRAS, 659, 1265',
+                                        'url': 'http://adsabs.harvard.edu/abs/2007ApJ...659.1265S'},
                              'DIMS14': {'ref': 'Delgado-Inglada, Morisset and Stasinska, 2014, MNRAS',
                                         'url':'http://arxiv.org/abs/1402.4852'}
                              }
@@ -770,7 +904,7 @@ class ICF(object):
         """
         return self.all_icfs[label]['comment']
 
-    def getElemAbundance(self, atom_abun, icf_list=[], absentIon=np.nan, use_coll=True):
+    def getElemAbundance(self, atom_abun, icf_list=[], icf_family=None, absentIon=np.nan, use_coll=True):
         """
         Compute elemental abundances from ionic abundances. The complete iventory is printed through pn.ICF().printAllICFs().
         See the ICF class for more details.
@@ -779,6 +913,7 @@ class ICF(object):
         Parameters: 
            - atom_abun    a dictionary of ionic abundances
            - icf_list     a list of selected ICFs (default: all)
+           - icf_family   a string common to all the icf one want to use, e.g. "DIMS14"
            - use_coll     In case both collision lines and recombination lines abundances exists:
                            if True (default), use collision line ionic abundance, if false use recombination ones  
         Usage:
@@ -789,6 +924,8 @@ class ICF(object):
         if type(icf_list) == type(''):
             icf_list = [icf_list]
         # List of all existing atoms. Necessary to initialize the ionic abundance dictionary
+        if icf_family is not None:
+            icf_list = [icf for icf in self.all_icfs.keys() if icf_family in icf]
         atom_list = []
         for elem in ELEM_LIST:
             for spec in SPEC_LIST:
@@ -840,11 +977,12 @@ class ICF(object):
                     except:
                         do_one_more_pass = True
                         if i_pass == self._max_pass:
-                            pn.log_.warn('{0} can not be evaluated'.format(self.all_icfs[icf_label]['icf']),
+                            pn.log_.warn('{0} cannot be evaluated'.format(self.all_icfs[icf_label]['icf']),
                                          calling=self.calling)
 
         self.elem_abun = elem_abun
         return self.elem_abun
+#            elem_abun[icf.all_icfs[icf_ref]['elem']] = np.log10(elem_abun_dic[icf_ref])+12
 
     def __getElemAbundanceFromStategy(self, atom_abun, strategy):
         """
