@@ -47,7 +47,7 @@ class RedCorr(object):
             - E_BV [float]: differential extinction between bands B and V
             - R_V = AV/E_BV
             - law [str]: one of the defined laws (available with RedCorr.getLaws()) 
-            - cHbeta: logarithmic extinction a Hbeta (prevalence on E_BV)
+            - cHbeta: logarithmic extinction at Hbeta (prevalence on E_BV)
             - UserFunction X(wave, param): A user-defined function that accept 2 parameters: wavelength(s) in Angstrom 
             and an optional parameter and return X(lambda) = A(lambda)/E_BV = R.A(lambda)/AV. 
             The correction is: 10**(0.4*E_bv*X)
@@ -150,17 +150,26 @@ class RedCorr(object):
         return self.__law
     def _get_cHbeta(self):
         return self.__cHbeta
+    def _get_AV(self):
+        return self.__AV
     def _get_uf(self):
         return self.__user_function
     
     def _set_e_bv(self, value):
         self.__E_BV = np.asarray(value)
         self.__cHbeta = self.cHbetaFromEbv(self.__E_BV)
+        self.__AV = self.__E_BV * self.R_V
         self._given = 'E_BV'
     def _set_cHbeta(self, value):
         self.__cHbeta = np.asarray(value)
         self.__E_BV = self.EbvFromCHbeta(self.__cHbeta)
+        self.__AV = self.__E_BV * self.R_V
         self._given = 'cHbeta'
+    def _set_AV(self, value):
+        self.__AV = np.asarray(value)
+        self.__E_BV = self.__AV / self.R_V
+        self.__cHbeta = self.cHbetaFromEbv(self.__E_BV)
+        self._given = 'AV'
     def _set_r_v(self, value):       
         self.__R_V = np.asarray(value)
     def _set_law(self, value):
@@ -175,6 +184,8 @@ class RedCorr(object):
                 self.E_BV = self.E_BV
             elif self._given == 'cHbeta':  
                 self.cHbeta = self.cHbeta
+            elif self._given == 'AV':  
+                self.AV = self.AV
     def _set_uf(self, value):
         self.__user_function = value
         if value is None:
@@ -187,12 +198,14 @@ class RedCorr(object):
             _uf2.__doc__ = self.__user_function.__doc__
             self._laws_dict['user'] = _uf2
         
+    
     E_BV = property(_get_e_bv, _set_e_bv, None, None)
     R_V = property(_get_r_v, _set_r_v, None, None)
     law = property(_get_law, _set_law, None, None)
     cHbeta = property(_get_cHbeta, _set_cHbeta, None, None)
+    AV = property(_get_AV, _set_AV, None, None)
     UserFunction = property(_get_uf, _set_uf, None, None)
-        
+    
         
     def getCorr(self, wave, rel_wave=None): 
         """
@@ -284,9 +297,9 @@ class RedCorr(object):
             self.E_BV = 2.5 * np.log10(obs_over_theo) / (f1 - f2)
         else:
             self.E_BV = 0.
+        del COR
 
-
-    def plot(self, w_inf=1000., w_sup=10000., laws=None, **kwargs):
+    def plot(self, w_inf=1000., w_sup=10000., laws=None, ax=None, **kwargs):
         """
         Plot extinction laws
 
@@ -294,9 +307,12 @@ class RedCorr(object):
             - w_inf [float] lower limit of plot
             - w_sup [float] upper limit of plot
             - laws [list of strings] list of extinction law labels. If set to 'all', all the laws are plotted
+            - ax : an axis object. If None, onr is created
             - **kwargs arguments to plot
 
         """
+        if ax is None:
+            f, ax = plt.subplots()
         colors = ['r', 'g', 'b', 'y', 'm', 'c']
         styles = ['-', '--', '-:', ':']
         if not pn.config.INSTALLED['plt']:
@@ -311,15 +327,15 @@ class RedCorr(object):
             laws = self.getLaws()
         if type(laws) is str:
             laws = [laws]
-        laws = laws.sort()    
+        laws.sort()    
         for i, law in enumerate(laws):
             self.law = law
             corr = self.getCorrHb(w)
             if corr is not None:
-                plt.plot(w, np.log10(corr), label=law, c=colors[i % 6], linestyle=styles[i // 6], **kwargs)
-        plt.legend()
-        plt.xlabel('Wavelength (A)')
-        plt.ylabel('X')
+                ax.plot(w, np.log10(corr), label=law, c=colors[i % 6], linestyle=styles[i // 6], **kwargs)
+        ax.legend()
+        ax.set_xlabel('Wavelength (A)')
+        ax.set_ylabel('X')
         self.law = old_law
         self.E_BV = old_E_BV
     
@@ -329,12 +345,10 @@ class RedCorr(object):
         Cardelli, Clayton & Mathis 1989, ApJ 345, 245
         http://adsabs.harvard.edu/abs/1989ApJ...345..245C
 
-        Comments:
-        Depends on R_V
+        Comments: Depends on R_V
 
-        Scope:     
-        UV through IR
-        Applicable to both dense and diffuse ISM
+        Scope: Applicable to both dense and diffuse ISM
+        Range: UV through IR
         
         """
         x = 1e4 / np.asarray([wave]) # inv microns
@@ -388,8 +402,7 @@ class RedCorr(object):
         Based on observation of Orion stars
         Depends on R_V
 
-        Scope:     
-        UV through IR
+        Range: UV through IR
         
         """
         x = 1e4 / np.asarray([wave]) # inv microns
@@ -426,10 +439,11 @@ class RedCorr(object):
         
         Xx = self.R_V * a + b
         return np.squeeze(Xx)
+    
 
     def _CCM89_oD94(self, wave):
         """
-        Galactic extinction law based on Cardelli et al 1989, modified by O'Donnel 1994
+        Galactic extinction law based on Cardelli et al 1989, modified by O'Donnell 1994
         for 1.1 < x < 3.3 (9100 < lambda < 3030)
         
         O'Donnell 1994, ApJ, 422, 1580
@@ -442,8 +456,8 @@ class RedCorr(object):
         Revised values for 1.1<x<3.3
         Produces lower correction in the near UV at low R_V
         
-        Scope:
-        UV through IR
+        Scope: Galactic
+        Range: UV through IR
         
         """
         x = 1e4 / np.asarray([wave]) # inv microns
@@ -480,6 +494,7 @@ class RedCorr(object):
         Xx = self.R_V * a + b
         return np.squeeze(Xx)
 
+
     def _S79_H83_CCM89(self, wave):
         """
         Galactic extinction law (0-33000 A range):
@@ -494,6 +509,8 @@ class RedCorr(object):
         Cardelli, Clayton and Mathis 1989, ApJ, 345, 245
         http://adsabs.harvard.edu/abs/1989ApJ...345..245C
         
+        Scope: Galactic
+        Range: UV through IR
         
         """
         x = 1e4 / np.asarray([wave]) # inv microns
@@ -584,15 +601,16 @@ class RedCorr(object):
         the extinction law (X(1/lambda)).
         It cannot be used for absolute correction.
         
-        Scope:
-        UV through IR
+        Range: 3000 to >20000
         
         """
         w = np.asarray([wave]) # inv microns
-
+        if self.E_BV == 0.:
+            return np.ones_like(w)
         f_tab = np.loadtxt(execution_path('Gal_Kaler.txt'))
         f = np.interp(w, f_tab[:, 0], f_tab[:, 1])
         return np.squeeze(f * self.cHbeta / 0.4 / self.E_BV)
+    
 
     def _SM79_Gal(self, wave):
         """
@@ -604,9 +622,8 @@ class RedCorr(object):
         Average of several extinction laws
         R_V=3.1
         
-        Scope:
-        UV through IR
-        Galactic
+        Scope: Galactic
+        Range: UV through IR
         
         """
         x = 1e4 / np.asarray([wave]) # inv microns
@@ -615,6 +632,7 @@ class RedCorr(object):
         Xx = np.interp(x, X_tab[:, 0], X_tab[:, 1])
         return np.squeeze(Xx)
     
+    
     def _G03_LMC(self, wave):
         """
         Extinction curve for the LMC
@@ -625,8 +643,8 @@ class RedCorr(object):
         Average curve for the LMC
         R_V = 3.41
 
-        Scope:    
-        LMC
+        Scope: LMC
+        Range: 1200 through fIR   
 
         """
         x = 1e4 / np.asarray([wave]) # inv microns
@@ -639,7 +657,7 @@ class RedCorr(object):
     def _F99_like(self, wave):
         """
         In the UV, it returns the Fitzpatrick & Massa 1990 law.
-        In the opt/IR, it returns the Fitzpatrick 1990 law. 
+        In the opt/IR, it returns the Fitzpatrick & Massa 1990 law. 
         
         Fitzpatrick 1999, PASP, 11, 63
         http://adsabs.harvard.edu/abs/1999PASP..111...63F
@@ -648,10 +666,9 @@ class RedCorr(object):
         
         Comments:
         The FM90 depends on 6 parameters which must be set by the user and are stored in RedCorr.FitzParams.
-        For the predefined set of parameters defined in FM99, use instead the F_99 method.
+        For the predefined set of parameters defined in FM99, use instead the F99 law.
         R_V must be provided, as the law depends on it. The dependence with R_V follows Table 4 in the F99 paper 
 
-        Scope:    
         Range: UV through IR
         
         """
@@ -770,8 +787,9 @@ class RedCorr(object):
             
     def _MCC99_FM90_LMC(self, wave):
         """
-        This method returns the UV extinction curve proposed for the LMC 
+        In the UV, this method returns the extinction curve proposed for the LMC 
         by Misselt et al 1999 based on the 1990 variant of the Fitzpatrick & Massa law
+        In the opt/IR, it returns the Fitzpatrick & Massa 1990 law.
 
         Misselt, Clayton & Gordon 1999 , ApJ, 515, 128 
         http://adsabs.harvard.edu/abs/1999ApJ...515..128M
@@ -786,13 +804,10 @@ class RedCorr(object):
         We refer to FM90 and not to the original FM88 because the value of a constant in F(lambda) slightly changed (0.0564 -> 0.05644)
         The value of another constant of F(lambda) appears to change from FM90 to MCC99, but it is probably a typo (0.5392 -> 0.5329) 
         
-        Scope:
-        Only UV
+        Scope: LMC
 
         """
-        if (wave > 3125.): # The cutoff is taken from Fig 3 of MCC99. Couldn't find the number anywhere.
-            pn.log_.warn('MCC89 law only defined for lambda < 3125A', calling=self.calling)
-            return None
+    
         x0 = 4.596  
         gamma = 0.91
         c1 = -1.28
@@ -819,8 +834,7 @@ class RedCorr(object):
         which includes an explicit dependence on R_V.
         R_V must be provided, as the law depends on its value.
         
-        Scope:
-        UV through IR
+        Range: UV through IR
 
         """
         x0 = 4.596  
@@ -849,8 +863,8 @@ class RedCorr(object):
         here set to the LMC values derived in FM88
         R_V must be provided, as the law depends on it
         
-        Scope:
-        UV through IR
+        Scope: LMC
+        Range: UV through IR
 
         """
         x0 = 4.608
@@ -862,6 +876,7 @@ class RedCorr(object):
         self.FitzParams = [x0, gamma, c1, c2, c3, c4]
         return self._F99_like(wave)
     
+    
     def _zeros(self, wave):
         """
         No correction, return 0.0
