@@ -236,7 +236,6 @@ class DataPlot(object):
                 except:
                     pn.log_.warn('Problem with plotting a subplot {} {}'.format(i,j), calling=self.calling)
         
-        plt.tight_layout(pad=0.1)
         plt.subplots_adjust(left=0.15, right=0.95, top=0.95, bottom=0.12)
         plt.gca().get_yaxis().get_major_formatter().set_useOffset(False)
         ax=plt.subplot(atom_n_max - 1, atom_n_max - 1, (atom_n_max-1)*(atom_n_max-2) + 1)
@@ -253,6 +252,7 @@ class DataPlot(object):
             y_txt = .85 - .04*i 
             fig.text(x_txt, y_txt, "Ref. %d: %s" %(i+1, data['ID']), color=color[i], ha = 'right') 
 
+        plt.tight_layout(pad=0.1)
         if save:
             plt.savefig(self.atom_rom + "_all_As.pdf")
     
@@ -364,7 +364,8 @@ class DataPlot(object):
                 plt.show()      
 
 
-    def plotOmega(self, save=False, figsize=(18, 12), fignum=None, scan_orders=None, NLevels=None):
+    def plotOmega(self, save=False, figsize=(18, 12), fignum=None, scan_orders=None, NLevels=None,
+                  fig=None):
         """
         Plot the tabulated collision strengths of each data set and the fit that is performed by PyNeb
         
@@ -382,7 +383,8 @@ class DataPlot(object):
         # Plotting range somewhat larger than actual data range (less tight) 
         if not pn.config.INSTALLED['plt']:
             pn.log_.error('Matplotlib not installed!', calling=self.calling)
-        fig = plt.figure(fignum, figsize=figsize)
+        if fig is None:
+            fig = plt.figure(fignum, figsize=figsize)
         plt.autoscale(tight=False)
         # I need two 
         first = True
@@ -448,7 +450,7 @@ class DataPlot(object):
                  color="#191970", fontsize=16, ha='center')
         plt.legend(legend_lines, legend_text, loc='upper right', borderpad=1, 
                    labelspacing=1, bbox_to_anchor=(1, 1 * coll_n_max))
-        
+        #plt.tight_layout()
         if save:
             plt.savefig(self.atom_rom + "_CS.pdf")
         
