@@ -66,11 +66,16 @@ LINE_LABEL_LIST['Fe3'] = ['4009A', '4659A', '4668A', '4701A', '4734A', '4755A',
                           '4925A', '4931A', '5412A', '4987A', '8729A', '8838A', '3240A', '3286A', '3319A', 
                           '3323A', '3335A', '3355A', '3357A', '3366A', '3371A', '3406A', '4046A', '4080A', '4097A', 
                           '4607A', '4770A', '4778A', '9701A', '9960A', '5440A', '6096A']
+LINE_LABEL_LIST['Fe4'] = ['4491A', '5685A', '5735A', '6740A']
+LINE_LABEL_LIST['Fe5'] = ['3783A', '3795A', '3829A', '3891A', '3895A', '3911A', '4071A', '4181A', '4227A']
+LINE_LABEL_LIST['Fe6'] = ['3556A', '3929A', '5146A', '5176A', '5278A', '5335A', '5370A', '5424A', '5427A', '5485A', '5631A', '5677A']
+LINE_LABEL_LIST['Fe7'] = ['5159A', '5276A', '5721A', '6087A']
 LINE_LABEL_LIST['K4'] = ['6102A', '6796A', '7109A', '2594A', '2711A', '2760A', '4511A', '6.0m', '4.3m', '15.4m']
 LINE_LABEL_LIST['K5'] = ['4163A', '4123A', '2514A', '6349A', '6446A', '2495A', '6222A', '6316A', '42.2m', '31.0m']
 LINE_LABEL_LIST['Kr3'] = ['6827A', '9902A', '3022A', '3504A', '3600A', '5423A', '2.2m', '1.88m', '13.1m', '1.07m']
 LINE_LABEL_LIST['Kr4'] = ['5868A', '5346A', '3219A', '7131A', '8091A', '2993A', '6108A', '6798A', '6.0m', '4.26m']
 LINE_LABEL_LIST['Kr5'] = ['5069A', '6256A', '8243A', '2550A', '2819A', '3163A', '5132A', '2.67m', '1.32m', '2.6m']
+LINE_LABEL_LIST['Mg4'] = ['4.5m']
 LINE_LABEL_LIST['Mg5'] = ['2783A', '2929A', '2992A', '1294A', '1325A', '1338A', '2418A', '5.6m', '3.96m', '13.5m']
 LINE_LABEL_LIST['Mg7'] = ['2441A', '2509A', '2629A', '1174A', '1190A', '1216A', '2261A', '943A', '953A', '970A', 
                           '1537A', '4790A', '9.0m', '3.42m', '5.5m']
