@@ -33,14 +33,14 @@ class _ManageAtomicData(object):
         
     def getPredefinedDataFileDict(self, data_dict=None):
         """
-        Retrieve a predefined dictionary of atomic data (either the default one [data_dict unspecified]
-        or another one [identified by data_dict])
+        Retrieve all predefined dictionaries of atomic data (or a specified one if data_dict is specified)
         
         Parameters:
-           - data_dict    name of the dictionary 
+           - data_dict    name of the dictionary (default: None)
 
         """
-        
+#        Retrieve a predefined dictionary of atomic data (either the default one [data_dict unspecified]
+#        or another one [identified by data_dict])
         if data_dict is None:
             return self._predefinedDataFileDict
         elif data_dict in self._predefinedDataFileDict:
@@ -154,17 +154,19 @@ class _ManageAtomicData(object):
         for dir in self._DataFilePaths:
             if data_file in os.listdir(dir):
                 return dir
-        strs = data_file.split('_')
-        elem = strs[0].capitalize()
-        spec = roman_to_int(strs[1])
-        atom = elem + str(spec)
-        strs = re.split(r'[_.]+',data_file)
-        data_type = strs[2]
-        if (data_type == 'atom') and (atom2chianti(atom) in self.ChiantiIONS['atom']):
-            return('{}/{}/{}'.format(self.Chianti_path, elem.lower(), atom2chianti(atom)))
-        if (data_type == 'coll') and (atom2chianti(atom) in self.ChiantiIONS['coll']):
-            return('{}/{}/{}'.format(self.Chianti_path, elem.lower(), atom2chianti(atom)))
-        return None
+        if data_file.split('.')[-1] == 'chianti':
+            strs = data_file.split('_')
+            elem = strs[0].capitalize()
+            spec = roman_to_int(strs[1])
+            atom = elem + str(spec)
+            strs = re.split(r'[_.]+',data_file)
+            data_type = strs[2]
+            if (data_type == 'atom') and (atom2chianti(atom) in self.ChiantiIONS['atom']):
+                return('{}/{}/{}'.format(self.Chianti_path, elem.lower(), atom2chianti(atom)))
+            if (data_type == 'coll') and (atom2chianti(atom) in self.ChiantiIONS['coll']):
+                return('{}/{}/{}'.format(self.Chianti_path, elem.lower(), atom2chianti(atom)))
+        else:
+            return None
  
     
     def printDirForAllFiles(self):
@@ -192,12 +194,12 @@ class _ManageAtomicData(object):
             
         Parameters:
            - atom        atom name
-           - data_type   either 'rec', 'atom' or 'coll'
+           - data_type   either 'rec', 'atom', 'coll' or 'trc'
 
         """
         file_list = []
         if data_type is None:
-            data_types = ['atom', 'coll', 'rec']
+            data_types = ['atom', 'coll', 'rec', 'trc']
         else:
             data_types = [data_type]
         if atom is not None:
@@ -299,7 +301,7 @@ class _ManageAtomicData(object):
             
         Parameters:
             - atom        selected atom
-            - data_type   type of atomic data ('atom', 'coll', 'rec')
+            - data_type   type of atomic data ('atom', 'coll', 'rec', 'trc')
             - warn        warn if no associated data file is found
         
         """
@@ -316,8 +318,9 @@ class _ManageAtomicData(object):
         if data_type is None:
             return(self.getDataFile(atom, 'atom', warn=warn),
                    self.getDataFile(atom, 'coll', warn=warn),
-                   self.getDataFile(atom, 'rec', warn=warn))
-        if data_type not in ('atom', 'coll', 'rec'):
+                   self.getDataFile(atom, 'rec', warn=warn),
+                   self.getDataFile(atom, 'trc', warn=warn))
+        if data_type not in ('atom', 'coll', 'rec', 'trc'):
             if warn:
                 self.log_.warn('{0} type unknown'.format(data_type), calling=self.calling)
             return None
@@ -340,7 +343,7 @@ class _ManageAtomicData(object):
         
         Parameters:
             - atom        selected atom
-            - data_type   type of atomic data ('atom', 'coll', 'rec')
+            - data_type   type of atomic data ('atom', 'coll', 'rec', 'trc')
             - warn        warn if no associated data file is found
         
         """
@@ -371,7 +374,7 @@ class _ManageAtomicData(object):
                     atom = elem + spec
                     if atom not in self._DataFileDict:
                         self._DataFileDict[atom] = {}
-                    if names[2] in ('atom', 'coll', 'rec'):
+                    if names[2] in ('atom', 'coll', 'rec', 'trc'):
                         self.setDataFile(atom, names[2], file_)
  
     def setDataFile(self, data_file=None, atom=None, data_type=None):
@@ -402,7 +405,7 @@ class _ManageAtomicData(object):
         if data_type is None:
             strs = re.split(r'[_.]+',data_file)
             data_type = strs[2]
-        if data_type not in ('atom', 'coll', 'rec'):
+        if data_type not in ('atom', 'coll', 'rec', 'trc'):
             self.log_.error('{0} is not a valid type'.format(data_type))
             return None
         if elem not in ELEM_LIST:
@@ -427,10 +430,11 @@ class _ManageAtomicData(object):
 
     def printAllSources(self, at_set=None, predef=None):
         """
-        Print bibliographic sources for atomic data of a set of atoms.
+        Print bibliographic sources of the adopted data sets of a list of atoms.
         
         Usage:
         pn.atomicData.printAllSources(['O3', 'Ar4', 'S2'])
+        pn.atomicData.printAllSources([O, S])
         pn.atomicData.printAllSources()
 
         Parameters: 
@@ -442,7 +446,16 @@ class _ManageAtomicData(object):
         if (type(at_set) == list) or (type(at_set) == tuple):
             at_dict = {}
             for item in at_set:
-                at_dict[item] = pn.Atom(pn.utils.misc.parseAtom(item)[0], pn.utils.misc.parseAtom(item)[1])
+                atom = pn.utils.misc.parseAtom(item)[0]
+                spec = pn.utils.misc.parseAtom(item)[1]
+                if spec is '':
+                    for ispec in SPEC_LIST:
+                        try:
+                            at_dict[atom+ispec] = pn.Atom(atom, ispec)
+                        except:
+                            pass
+                else:
+                    at_dict[item] = pn.Atom(atom, spec)
         elif at_set is not None:
             pn.log_.error('The argument at_set must be a list or a tuple', calling=self.calling)
             return None
@@ -480,7 +493,7 @@ class _ManageAtomicData(object):
                         if os.path.exists(atom_file):
                             self.ChiantiIONS['atom'].append(atom)
             except:
-                pn.log_.warn('File not found {}, no Chianti data vailable'.format(masterlist), 
+                pn.log_.warn('File not found {}, no Chianti data available'.format(masterlist), 
                              calling='_initChianti')
         
     def printPoem(self, yr=0):
@@ -520,6 +533,7 @@ class _ManageAtomicData(object):
             else:
                 self.printPoem(yr=96)
 
+
 def extract_flt(str_):
     """
     Return the first float in str_, removing the no digit (and no dot) leading part of it.
@@ -584,15 +598,16 @@ def readNIST(NISTfile):
     data = data.astype([('conf', 'a23'), ('term', 'a9'), ('J', 'float'), ('energy', 'float'), ('ref', 'a10')])
     return data
 
+
 def getLevelsNIST(atom, Nmax = None):
     """
-    return a numpy.array containing the NIST data related to the levels for the given atom
+    Return a numpy.array containing the NIST data related to the levels for the given atom
     The keys of the recarry are: conf, term, J, energy, ref
     Example:
         data = getLevelsNIST('O3')
         energies = data['energy']
+        
     """
-    
     elem, spec = parseAtom(atom)
     elem = elem.lower()
     spec = int_to_roman(int(spec)).lower()
@@ -609,9 +624,11 @@ def getLevelsNIST(atom, Nmax = None):
     else:
         return None
     
+    
 def _atom_fits2ascii(filename):
     """
     Transform a *atom*.fits file into an *atom*.dat file.
+    
     """
     strs = filename.split('/')[-1].split('_')
     elem = strs[0].capitalize()
@@ -653,6 +670,7 @@ def _atom_fits2ascii(filename):
 def _coll_fits2ascii(filename, overwrite=None):
     """
     Transform a *coll*.fits file into an *coll*.dat file.
+    
     """
     strs = filename.split('/')[-1].split('_')
     elem = strs[0].capitalize()
