@@ -287,10 +287,10 @@ def get_reduced(N_rand, a, value_method = 'original', error_method='std'):
     else:
         from scipy.stats.mstats import mquantiles
     
-    value = a[0]
-    error = a.std()
     
-    if value_method == 'mean':
+    if value_method == 'original':
+        value = a[0]
+    elif value_method == 'mean':
         value = a.mean()
     elif value_method == 'median':
         value = np.median(a)
@@ -298,11 +298,28 @@ def get_reduced(N_rand, a, value_method = 'original', error_method='std'):
     if error_method == 'quants':
         quants = mquantiles(a, [0.16, 0.84])
         error = np.abs(quants - value).mean()
+    elif error_method == 'uquants':
+        quants = mquantiles(a, [0.16, 0.84])
+        error = quants[1] - value
+    elif error_method == 'lquants':
+        quants = mquantiles(a, [0.16, 0.84])
+        error = quants[0] - value
         # error = (quants[1]-quants[0])/2)
-    
+    elif error_method == 'upper':
+        mask = (a - value) >= 0
+        error =  ((((a[mask] - value)**2).sum())/np.float(mask.sum()))**0.5
+    elif error_method == 'lower':
+        mask = (a - value) <= 0
+        error = -((((a[mask] - value)**2).sum())/np.float(mask.sum()))**0.5
+    elif error_method == 'std':
+        error = a.std()
+    else:
+        pn.log_.error('Unknown error method {}'.format(error_method))
+        
     return (value, error)
     
-def get_reduced_dic(N_rand, n_obs_ori, dic, value_method = 'original', error_method='std', abund12 = False):
+def get_reduced_dic(N_rand, n_obs_ori, dic, value_method = 'original', 
+                    error_method='std', abund12 = False):
     """
     This function returns a dictionary of values (ionic or atomic abundances, temp...) and errors.
     It takes as argument a dictionary that is supposed to contains n_obs_ori values from
@@ -329,7 +346,8 @@ def get_reduced_dic(N_rand, n_obs_ori, dic, value_method = 'original', error_met
                 value.append(np.NAN)
                 error.append(0.0)
             else:
-                v, e = get_reduced(N_rand, values[tt], value_method = value_method, error_method=error_method)
+                v, e = get_reduced(N_rand, values[tt], value_method = value_method, 
+                                   error_method=error_method)
                 value.append(v)
                 error.append(e)
         res[key] = np.array(value)
