@@ -79,6 +79,7 @@ IP['Fe3'] = 16.188
 IP['Fe4'] = 30.652
 IP['Fe5'] = 54.8
 IP['Fe6'] = 75.0
+IP['Fe7'] = 98.99
 IP['Ni1'] = 0.
 IP['Ni2'] = 7.639877
 IP['Ni3'] = 18.168837
@@ -148,6 +149,10 @@ gsDict = {
             'p5': ['Ne2', 'Na3', 'Si6', 'Cl1', 'Ar2', 'K3', 'Ba4'],
             's1': ['C4', 'N5', 'Ba2'],
             's2': ['C3', 'N4', 'O5', 'Si3'],
+            'd2': ['Fe7'],
+            'd3': ['Fe6'],
+            'd4': ['Fe5'],
+            'd5': ['Fe4'],
             'd6': ['Fe3'],
             'd8': ['Ni3']
             }
@@ -167,6 +172,8 @@ gsLevelDict = {
             'p5': ['$^2$P$_{3/2}$', '$^2$P$_{1/2}$'],
             's1': ['$^2$S$_{1/2}$', '$^2$P$_{1/2}$', '$^2$P$_{3/2}$'],
             's2': ['$^1$S$_0$', '$^3$P$_0$', '$^3$P$_1$', '$^3$P$_2$', '$^1$P$_1$'],
+            'd2': ['$^3$F$_{2}$', '$^3$F$_{3}$', '$^3$F$_{4}$','$^1$D$_{2}$', '$^3$P$_{0}$', '$^3$P$_{1}$', '$^3$P$_{2}$', '$^1$G$_{4}$', '$^1$S$_{0}$'], 
+            'd3': ['$^4$F$_{3/2}$', '$^4$F$_{5/2}$', '$^4$F$_{7/2}$','$^4$F$_{9/2}$', '$^4$P$_{1/2}$', '$^4$P$_{3/2}$', '$^4$P$_{5/2}$', '$^2$G$_{7/2}$', '$^2$G$_{9/2}$', '$^2$P$_{3/2}$', '$^2$P$_{1/2}$', '$^2$D2$_{5/2}$', '$^2$D2$_{3/2}$', '$^2$H$_{9/2}$', '$^2$H$_{11/2}$', '$^2$F$_{7/2}$', '$^2$F$_{5/2}$', '$^2$D1$_{5/2}$', '$^2$D1$_{3/2}$'], 
             'd6': ['$^5$D$_4$', '$^5$D$_3$', '$^5$D$_2$', '$^5$D$_1$', '$^5$D$_0$', '$^3$P2$_2$', '$^3$H$_6$'], 
             'd8': ['$3$F$_4$', '$^3$F$_3$', '$^3$F$_2$', '$^1$D$_2$', '$^3$P$_2$', '$^3$P2$_1$', '$^3$P$_0$']
             }
@@ -212,7 +219,7 @@ _predefinedDataFileDict = {'IRAF_09_orig':
                             },
                          'IRAF_09':
                            {'H1': {'rec': 'h_i_rec_SH95.fits'},
-                            'He1': {'rec': 'he_i_rec_P12corr13.fits'},
+                            'He1': {'rec': 'he_i_rec_Pal12-Pal13.fits'},
                             'He2': {'rec': 'he_ii_rec_SH95.fits'},
                             'Al2': {'atom': 'al_ii_atom_JSP86-HK87-VVF96-KS86.fits', 'coll': 'al_ii_coll_KHAF92-TBK85-TBK84.fits'},
                             'Ar2': {'atom': 'ar_ii_atom_Bal06.fits', 'coll': 'ar_ii_coll_PB95.fits'},
@@ -253,7 +260,7 @@ _predefinedDataFileDict = {'IRAF_09_orig':
                             },
                            'PYNEB_13_01':
                             {'H1': {'rec': 'h_i_rec_SH95.fits'},
-                             'He1': {'rec': 'he_i_rec_P12corr13.fits'},
+                             'He1': {'rec': 'he_i_rec_Pal12-Pal13.fits'},
                              'He2': {'rec': 'he_ii_rec_SH95.fits'},
                              'Al2': {'atom': 'al_ii_atom_JSP86-HK87-VVF96-KS86.fits', 'coll': 'al_ii_coll_KHAF92-TBK85-TBK84.fits'},
                              'Ar2': {'atom': 'ar_ii_atom_Bal06.fits', 'coll': 'ar_ii_coll_PB95.fits'},
@@ -301,7 +308,7 @@ _predefinedDataFileDict = {'IRAF_09_orig':
                              },
                            'PYNEB_14_01':
                             {'H1': {'rec': 'h_i_rec_SH95.fits'},
-                             'He1': {'rec': 'he_i_rec_P12corr13.fits'},
+                             'He1': {'rec': 'he_i_rec_Pal12-Pal13.fits'},
                              'He2': {'rec': 'he_ii_rec_SH95.fits'},
                              'Al2': {'atom': 'al_ii_atom_JSP86-HK87-VVF96-KS86.fits', 'coll': 'al_ii_coll_KHAF92-TBK85-TBK84.fits'},
                              'Ar2': {'atom': 'ar_ii_atom_Bal06.fits', 'coll': 'ar_ii_coll_PB95.fits'},
@@ -360,7 +367,7 @@ _predefinedDataFileDict = {'IRAF_09_orig':
                              },
                            'PYNEB_14_02':
                             {'H1': {'rec': 'h_i_rec_SH95.fits'},
-                             'He1': {'rec': 'he_i_rec_P12corr13.fits'},
+                             'He1': {'rec': 'he_i_rec_Pal12-Pal13.fits'},
                              'He2': {'rec': 'he_ii_rec_SH95.fits'},
                              'Al2': {'atom': 'al_ii_atom_JSP86-HK87-VVF96-KS86.dat', 'coll': 'al_ii_coll_KHAF92-TBK85-TBK84.dat'},
                              'Ar2': {'atom': 'ar_ii_atom_Bal06.dat', 'coll': 'ar_ii_coll_PB95.dat'},
@@ -419,9 +426,9 @@ _predefinedDataFileDict = {'IRAF_09_orig':
                              'Rb6': {'atom': 'rb_vi_atom_BH86.dat', 'coll': 'rb_vi_coll_S97.dat'}
                              },
                            'PYNEB_14_03':
-                            {'H1': {'rec': 'h_i_rec_SH95.fits'},
-                             'He1': {'rec': 'he_i_rec_P12corr13.fits'},
-                             'He2': {'rec': 'he_ii_rec_SH95.fits'},
+                            {'H1': {'rec': 'h_i_rec_SH95.fits', 'trc': 'h_i_trc_SH95-caseB.dat'},
+                             'He1': {'rec': 'he_i_rec_Pal12-Pal13.fits'},
+                             'He2': {'rec': 'he_ii_rec_SH95.fits', 'trc': 'he_ii_trc_SH95-caseB.dat'},
                              'Al2': {'atom': 'al_ii_atom_JSP86-HK87-VVF96-KS86.dat', 'coll': 'al_ii_coll_KHAF92-TBK85-TBK84.dat'},
                              'Ar2': {'atom': 'ar_ii_atom_Bal06.dat', 'coll': 'ar_ii_coll_PB95.dat'},
                              'Ar3': {'atom': 'ar_iii_atom_M83-KS86.dat', 'coll': 'ar_iii_coll_GMZ95.dat'},
@@ -439,6 +446,10 @@ _predefinedDataFileDict = {'IRAF_09_orig':
                              'Cl3': {'atom': 'cl_iii_atom_M83-KS86.dat', 'coll': 'cl_iii_coll_BZ89.dat'},
                              'Cl4': {'atom': 'cl_iv_atom_KS86-MZ82-EM84.dat', 'coll': 'cl_iv_coll_GMZ95.dat'},
                              'Fe3': {'atom': 'fe_iii_atom_Q96_J00.dat', 'coll': 'fe_iii_coll_Z96.dat'},
+                             'Fe4': {'atom': 'fe_iv_atom_FFRR08.dat', 'coll': 'fe_iv_coll_ZP97.dat'},
+                             'Fe5': {'atom': 'fe_v_atom_Nal00.dat', 'coll': 'fe_v_coll_BGMcL07.dat'},
+                             'Fe6': {'atom': 'fe_vi_atom_CP00.dat', 'coll': 'fe_vi_coll_CP99.dat'},
+                             'Fe7': {'atom': 'fe_vii_atom_WB08.dat', 'coll': 'fe_vii_coll_WB08.dat'},
                              'K4': {'atom': 'k_iv_atom_M83-KS86.dat', 'coll': 'k_iv_coll_GMZ95.dat'},
                              'K5': {'atom': 'k_v_atom_M83-KS86.dat', 'coll': 'k_v_coll_BZL88.dat'},
                              'Mg5': {'atom': 'mg_v_atom_GMZ97.dat', 'coll': 'mg_v_coll_BZ94.dat'},
